@@ -74,8 +74,6 @@ void SearchQuery::run(LatexDocument *doc)
 		break;
 	}
 
-	qDebug() << mScope;
-
 	foreach (LatexDocument *doc, docs) {
 		if (!doc) continue;
 		QList<QDocumentLineHandle *> lines;
@@ -85,7 +83,6 @@ void SearchQuery::run(LatexDocument *doc)
 			if (l < 0) break;
 			lines << doc->line(l).handle();
 		}
-		qDebug() << doc->getFileName() << lines.count();
 
 		if (!lines.isEmpty()) { // don't add empty searches
 			if (doc->getFileName().isEmpty() && doc->getTemporaryFileName().isEmpty())
@@ -104,6 +101,9 @@ QString SearchQuery::replacementText()
 {
 	return mModel->replacementText();
 }
+void SearchQuery::setExpression(QString expr){
+    mModel->setSearchExpression(expr,flag(IsCaseSensitive) ? Qt::CaseSensitive : Qt::CaseInsensitive, flag(IsWord), flag(IsRegExp));
+}
 
 void SearchQuery::replaceAll()
 {
