@@ -31,6 +31,14 @@ bool getDiskFreeSpace(const QString &path, quint64 &freeBytes)
 #endif
 }
 
+QLocale::Language getKeyboardLanguage() {
+#if QT_VERSION < 0x050000
+	return QApplication::keyboardInputLocale().language();
+#else
+	return QGuiApplication::inputMethod()->locale().language();
+#endif
+}
+
 /*!
  * Redefine or filter some shortcuts depending on the locale
  * On Windows, AltGr is interpreted as Ctrl+Alt so we shouldn't
@@ -42,11 +50,7 @@ QKeySequence filterLocaleShortcut(QKeySequence ks)
 #ifndef Q_OS_WIN32
 	return ks;
 #else
-#if QT_VERSION < 0x050000
-	QLocale::Language lang = QApplication::keyboardInputLocale().language();
-#else
-	QLocale::Language lang = QGuiApplication::inputMethod()->locale().language();
-#endif
+	QLocale::Language lang = getKeyboardLanguage();
 	switch (lang) {
 	case QLocale::Hungarian:
 		if (ks.matches(QKeySequence("Ctrl+Alt+F"))) {
@@ -60,6 +64,19 @@ QKeySequence filterLocaleShortcut(QKeySequence ks)
 			return QKeySequence("Ctrl+Alt+Shift+U");
 		}
 		break;
+	case QLocale::Turkish:
+		if (ks.matches(QKeySequence("Ctrl+Alt+F"))) {
+			return QKeySequence("Ctrl+Alt+Shift+F");
+		}
+		break;
+	case QLocale::Czech:
+		if (ks.matches(QKeySequence("Ctrl+Alt+S"))) {
+			return QKeySequence();
+		} else if (ks.matches(QKeySequence("Ctrl+Alt+F"))) {
+			return QKeySequence("Ctrl+Alt+Shift+F");
+		} else if (ks.matches(QKeySequence("Ctrl+Alt+L"))) {
+			return QKeySequence("Ctrl+Alt+Shift+L");
+		}
 	default:
 		return ks;
 	}
@@ -402,7 +419,6 @@ QString getNonextistentFilename(const QString &guess, const QString &fallback)
 	QFileInfo fi(guess);
 	if (!fi.exists()) return guess;
 	QRegExp reNumberedFilename("(.*[^\\d])(\\d*)\\.(\\w+)");
-	qDebug() << guess;
 	if (!reNumberedFilename.exactMatch(guess)) {
 		return fallback;
 	}
@@ -516,7 +532,6 @@ bool isRetinaMac()
 		QRegExp rx("MacBookPro([0-9]*)");
 		rx.indexIn(model);
 		int num = rx.cap(1).toInt();
-		//qDebug() << num << model;
 		if (num >= 10) // compatibility with future MacBookPros. Assume they are also retina.
 			isRetina = true;
 	}
